import os
import numpy as np
import pandas as pd
from debiastool.debias import fill_gaps
from debiastool.validation import plot_data, validate


def read_data(filename):
    df = pd.read_excel(filename, converters={'Date': pd.to_datetime}, encoding='utf-8')
    df = df.set_index('Date')
    return df


if __name__ == '__main__':
    os.chdir(os.path.dirname(__file__))  # go to __file__ dir (environment only)
    data = read_data('data/KikindaExample.xlsx')

    # make a gap in OBS (hide observations)
    data['OBSGAP'] = data['OBS']
    data['OBSGAP'].loc['2016-06-02':'2016-06-07'] = np.nan
    plot_data(data, start_date='2016-05-31 00:00:00', end_date='2016-06-09 00:00:00')

    # fill gaps
    filled_data = fill_gaps(data, diurnal_bias_filter=True)
    plot_data(filled_data, start_date='2016-05-31 00:00:00', end_date='2016-06-09 00:00:00')
    validate(filled_data)
