import matplotlib.pyplot as plt
import matplotlib.dates as mdates


def plot_data(data, start_date, end_date):
    styles = {'OBS': 'b--', 'OBSGAP': 'b-', 'ERA5': 'r-', 'DEB': 'g-'}
    fig = plt.figure(figsize=(8, 6))
    ax = fig.add_subplot(111)
    for col in data.columns:
        plt.plot(data[col], styles[col])
    plt.grid()
    plt.legend(loc='best')
    ax.set_xlim([start_date, end_date])
    ax.xaxis.set_major_formatter(mdates.DateFormatter('%Y-%m-%d'))
    plt.xticks(rotation=45)
    plt.title('2 m temperature [$^\circ C$]')
    plt.tight_layout()
    plt.show()


def plot_bias(scoring_data):
    fig = plt.figure(figsize=(8, 6))
    ax = fig.add_subplot(111)
    ax.plot(scoring_data['ERA5'] - scoring_data['OBS'], 'r-', label='ERA5')
    ax.plot(scoring_data['DEB'] - scoring_data['OBS'], 'g-', label='DEB')
    ax.xaxis.set_major_formatter(mdates.DateFormatter('%Y-%m-%d'))
    plt.grid()
    plt.legend(loc='best')
    plt.xticks(rotation=45)
    plt.title('BIAS')
    plt.tight_layout()
    plt.show()
    plt.close()


def plot_rmse(scoring_data):
    fig = plt.figure(figsize=(8, 6))
    ax = fig.add_subplot(111)
    ax.plot((scoring_data['ERA5'] - scoring_data['OBS']) ** 2, 'r-', label='ERA5')
    ax.plot((scoring_data['DEB'] - scoring_data['OBS']) ** 2, 'g-', label='OBS')
    ax.xaxis.set_major_formatter(mdates.DateFormatter('%Y-%m-%d'))
    plt.grid()
    plt.legend(loc='best')
    plt.xticks(rotation=45)
    plt.title('RMSE')
    plt.tight_layout()
    plt.show()
    plt.close()


def validate(filled_data):
    scoring_data = filled_data[~filled_data['DEB'].isnull()]
    print('ERA5:')
    print('mean BIAS:', (scoring_data['ERA5'] - scoring_data['OBS']).mean())
    print('mean RMSE:', ((scoring_data['ERA5'] - scoring_data['OBS']) ** 2).mean() ** 0.5)
    print('DEB:')
    print('mean BIAS:', (scoring_data['DEB'] - scoring_data['OBS']).mean())
    print('mean RMSE:', ((scoring_data['DEB'] - scoring_data['OBS']) ** 2).mean() ** 0.5)
    plot_bias(scoring_data)
    plot_rmse(scoring_data)
